com.biffweb.core

View README

Schema

:biff.core/init

(fn [modules-var]) => {...}. See start.

:biff.core/stop

(fn []) => nil. See start and stop.

:biff.core/secret

A Delay-like value returned by secret-delay. Meant to be used as a schema value:

(biff.core/register {:com.example/api-key :biff.core/secret})

:biff.core/kv-set

(fn [ctx namespace key value]) => nil

Sets the given key in namespace to value. A nil value should delete the key, i.e. a call to :biff.core/kv-list should only return keys with non-nil values.

  • namespace: qualified keyword, e.g. :com.example/things. The keyword's namespace should be owned by whatever library or application defines the keyword.
  • key: string.
  • value: any Clojure value that can be round-tripped through pr-str -> clojure.edn/read-string without custom options.

:biff.core/kv-get

(fn [ctx namespace key]) => value

Returns the value for the given key in namespace. If key is unset, returns nil. See :biff.core/kv-set.

:biff.core/kv-list

(fn [ctx namespace])
(fn [ctx namespace key-prefix]), => [key1, key2, ...]

Returns a sequence of sorted keys in the given namespace. See :biff.core/kv-set.

  • key-prefix: string. If set, returns only the keys beginning with this prefix.
[View README](/libs/core/)

## Schema

### :biff.core/init

`(fn [modules-var]) => {...}`. See [start](#start).

### :biff.core/stop

`(fn []) => nil`. See [start](#start) and [stop](#stop).

### :biff.core/secret

A `Delay`-like value returned by [secret-delay](#secret-delay).
Meant to be used as a schema value:

```clojure
(biff.core/register {:com.example/api-key :biff.core/secret})
```

### :biff.core/kv-set

`(fn [ctx namespace key value]) => nil`

Sets the given key in `namespace` to `value`. A nil value should delete the
key, i.e. a call to `:biff.core/kv-list` should only return keys with non-nil
values.

- `namespace`: qualified keyword, e.g. `:com.example/things`. The keyword's
  namespace should be owned by whatever library or application defines the
  keyword.
- `key`: string.
- `value`: any Clojure value that can be round-tripped through `pr-str` ->
`clojure.edn/read-string` without custom options.

### :biff.core/kv-get

`(fn [ctx namespace key]) => value`

Returns the value for the given key in `namespace.` If `key` is unset,
returns nil. See `:biff.core/kv-set`.

### :biff.core/kv-list

```
(fn [ctx namespace])
(fn [ctx namespace key-prefix]), => [key1, key2, ...]
```

Returns a sequence of sorted keys in the given namespace. See
`:biff.core/kv-set`.

- `key-prefix`: string. If set, returns only the keys beginning with this
prefix.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries