com.biffweb.core

The main framework/inversion-of-control code for Biff.

Contains functions for starting/stopping Biff applications and for validating data that needs to cross module/component boundaries.

GLOSSARY

system map: A map of namespaced keys that contains the state of the running Biff application.

modules: A collection of maps that together define your application's functionality.

components: A sequence of functions that start stateful resources and do other initialization needed by your application.

The main framework/inversion-of-control code for Biff.

Contains functions for starting/stopping Biff applications and for validating
data that needs to cross module/component boundaries.


GLOSSARY

system map:
  A map of namespaced keys that contains the state of the running Biff
  application.

modules:
  A collection of maps that together define your application's functionality.

components:
  A sequence of functions that start stateful resources and do other
  initialization needed by your application.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries