Helper code and schemas for the interfaces shared by all Biff libraries.
SCHEMA
:biff.core/init (fn [modules-var]) => {...}
See biff.core/start.
:biff.core/stop (fn []) => nil
See biff.core/start and biff.core/stop.
:biff.core/secret A Delay-like value returned by biff.core/secret-delay
:biff.core/kv-set (fn [ctx namespace key value]) => nil
Sets the given key in namespace to value. A nil value should delete the key, i.e. a call to :biff.core/kv-list should only return keys with non-nil values.
namespace Qualified keyword, e.g. :com.example/things. The keyword's namespace should be owned by whatever library or application defines the keyword.
key String.
value Any Clojure value that can be round-tripped through pr-str -> clojure.edn/read-string without custom options.
:biff.core/kv-get (fn [ctx namespace key]) => value
Returns the value for the given key in namespace. If key is unset, returns nil. See :biff.core/kv-set.
:biff.core/kv-list (fn [ctx namespace]), (fn [ctx namespace key-prefix]), => [key1, key2, ...]
Returns a sequence of sorted keys in the given namespace. See :biff.core/kv-set.
key-prefix String. If set, returns only the keys beginning with this prefix.
Helper code and schemas for the interfaces shared by all Biff libraries.
SCHEMA
:biff.core/init
(fn [modules-var]) => {...}
See biff.core/start.
:biff.core/stop
(fn []) => nil
See biff.core/start and biff.core/stop.
:biff.core/secret
A Delay-like value returned by biff.core/secret-delay
:biff.core/kv-set
(fn [ctx namespace key value]) => nil
Sets the given key in namespace to value. A nil value should delete the
key, i.e. a call to :biff.core/kv-list should only return keys with non-nil
values.
namespace
Qualified keyword, e.g. :com.example/things. The keyword's namespace
should be owned by whatever library or application defines the keyword.
key
String.
value
Any Clojure value that can be round-tripped through pr-str ->
clojure.edn/read-string without custom options.
:biff.core/kv-get
(fn [ctx namespace key]) => value
Returns the value for the given key in namespace. If key is unset, returns
nil. See :biff.core/kv-set.
:biff.core/kv-list
(fn [ctx namespace]),
(fn [ctx namespace key-prefix]), => [key1, key2, ...]
Returns a sequence of sorted keys in the given namespace. See
:biff.core/kv-set.
key-prefix
String. If set, returns only the keys beginning with this prefix.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |